import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { CallHistoryInfo } from '@ucap-webmessenger/pi';
import { NGXLogger } from 'ngx-logger';

import { VersionInfo2Response } from '@ucap-webmessenger/api-public';
import moment from 'moment';

@Component({
  selector: 'ucap-call-history',
  templateUrl: './call-history.component.html',
  styleUrls: ['./call-history.component.scss']
})
export class CallHistoryComponent implements OnInit {
  @Input()
  set callHistoryList(dataList: CallHistoryInfo[]) {
    if (!!dataList && dataList.length > 0) {
      this.callInfoList = dataList;
    }
  }
  callHistorys: CallHistoryInfo;

  @Input()
  dateChanged = false;

  @Output()
  clickTocall = new EventEmitter<string>();

  callInfoList: CallHistoryInfo[] = [];
  sendDate: string;
  sessionVerinfo: VersionInfo2Response;

  constructor(private logger: NGXLogger) {}

  ngOnInit() {}

  getDateSplitter(callHistory: CallHistoryInfo): boolean {
    const curIndex = this.callInfoList.findIndex(
      v =>
        v.calledDn === callHistory.calledDn &&
        v.startDate === callHistory.startDate
    );
    if (curIndex === 0) {
      return true;
    }
    if (curIndex > 0) {
      if (!this.callInfoList[curIndex]) {
        return false;
      }
      return !moment(this.callInfoList[curIndex].startDate).isSame(
        moment(this.callInfoList[curIndex - 1].startDate),
        'day'
      );
    }
    return false;
  }

  onClickToCall(callNum: string) {
    this.clickTocall.emit(callNum);
  }
}
